import 'package:dio/dio.dart';
import 'package:meta/meta.dart';

@immutable
class MyResponse<Body> {
  final Response base;
  final Body? body;

  const MyResponse(this.base, this.body);

  MyResponse replace<BodyType>({Response? base, BodyType? body}) =>
      MyResponse(base ?? this.base, body ?? this.body);

  MyResponse<Body> replaceWithNull<Body>({Response? base, required Body body}) =>
      MyResponse(base ?? this.base, body);

  int get statusCode => base.statusCode ?? 0;

  bool get isSuccessful => statusCode >= 200 && statusCode < 300;

  Headers get headers => base.headers;

  List<int> get bodyBytes => (body as List<int>).cast<int>();

  Map<String, dynamic> get extra => base.extra;

  RequestOptions get request => base.requestOptions;
}
